==> eslint-config-cssnano-2.1.0.tgz: package/index.js <==
module.exports = {
    'rules': {
        'babel/object-curly-spacing': 2,
        'brace-style': [2, '1tbs', {'allowSingleLine': false}],
        'camelcase': [2],
        'comma-spacing': [2],
        'curly': [2, 'all'],
        'dot-notation': [2],
        'eol-last': [2],
        'eqeqeq': [2],
        'handle-callback-err': [2],
        'indent': [2, 4],
        'keyword-spacing': [2],
        'new-cap': [2],
        'new-parens': [2],
        'no-alert': [2],
        'no-caller': [2],
        'no-const-assign': [2],
        'no-constant-condition': [2],
        'no-dupe-args': [2],
        'no-dupe-keys': [2],
        'no-empty': [2],
        'no-empty-character-class': [2],
        'no-eval': [2],
        'no-irregular-whitespace': [2],
        'no-labels': [2],
        'no-lonely-if': [2],
        'no-multiple-empty-lines': [2],
        'no-new': [2],
        'no-octal': [2],
        'no-proto': [2],
        'no-redeclare': [2],
        'no-shadow': [2],
        'no-shadow-restricted-names': [2],
        'no-sparse-arrays': [2],
        'no-undef': [2],
        'no-unreachable': [2],
        'no-unused-vars': [2],
        'no-useless-call': [2],
        'no-var': [2],
        'no-void': [2],
        'no-warning-comments': [2],
        'no-with': [2],
        'quote-props': [2, 'as-needed'],
        'prefer-arrow-callback': [2],
        'radix': [2],
        'semi': [2, 'always'],
        'semi-spacing': [2],
        'space-before-function-paren': [2, 'always'],
        'space-before-blocks': [2, 'always'],
        'spaced-comment': [2, 'always'],
        'strict': [2, 'global'],
        'yoda': [2, 'never']
    },
    'parserOptions': {
        'ecmaVersion': 6,
        'sourceType': 'module',
        'ecmaFeatures': {
            'experimentalObjectRestSpread': true
        },
    },
    'parser': 'babel-eslint',
    'plugins': [
        'babel'
    ],
    'env': {
        'node': true,
        'es6': true
    }
};

==> eslint-config-cssnano-3.0.0.tgz: package/index.js <==
module.exports = {
    'rules': {
        'babel/object-curly-spacing': 2,
        'brace-style': [2, '1tbs', {'allowSingleLine': false}],
        'camelcase': [2],
        'comma-dangle': [2, 'always-multiline'],
        'comma-spacing': [2],
        'curly': [2, 'all'],
        'dot-notation': [2],
        'eol-last': [2],
        'eqeqeq': [2],
        'handle-callback-err': [2],
        'import/export': [2],
        'import/imports-first': [2],
        'import/named': [2],
        'import/namespace': [2],
        'import/newline-after-import': [2],
        'import/no-duplicates': [2],
        'import/no-mutable-exports': [2],
        'import/no-named-as-default': [2],
        'import/no-named-as-default-member': [2],
        'import/no-unresolved': [2, {"commonjs": true}],
        'import/order': [2],
        'import/prefer-default-export': [2],
        'indent': [2, 4],
        'keyword-spacing': [2],
        'new-cap': [2],
        'new-parens': [2],
        'no-alert': [2],
        'no-caller': [2],
        'no-const-assign': [2],
        'no-constant-condition': [2],
        'no-dupe-args': [2],
        'no-dupe-keys': [2],
        'no-empty': [2],
        'no-empty-character-class': [2],
        'no-eval': [2],
        'no-irregular-whitespace': [2],
        'no-labels': [2],
        'no-lonely-if': [2],
        'no-multiple-empty-lines': [2],
        'no-new': [2],
        'no-octal': [2],
        'no-proto': [2],
        'no-redeclare': [2],
        'no-return-assign': [2],
        'no-self-assign': [2],
        'no-self-compare': [2],
        'no-shadow': [2],
        'no-shadow-restricted-names': [2],
        'no-sparse-arrays': [2],
        'no-undef': [2],
        'no-unreachable': [2],
        'no-unused-vars': [2],
        'no-useless-call': [2],
        'no-var': [2],
        'no-void': [2],
        'no-warning-comments': [2],
        'no-with': [2],
        'quote-props': [2, 'as-needed'],
        'prefer-arrow-callback': [2],
        'radix': [2],
        'semi': [2, 'always'],
        'semi-spacing': [2],
        'space-before-function-paren': [2, 'always'],
        'space-before-blocks': [2, 'always'],
        'spaced-comment': [2, 'always'],
        'strict': [2, 'global'],
        'yoda': [2, 'never'],
    },
    'parserOptions': {
        'ecmaVersion': 6,
        'sourceType': 'module',
        'ecmaFeatures': {
            'experimentalObjectRestSpread': true,
        },
    },
    'parser': 'babel-eslint',
    'plugins': [
        'babel',
        'import',
    ],
    'env': {
        'node': true,
        'es6': true,
    },
};
